// This is a simple example
package main

import (
	"os"
	"strings"

	"go.wit.com/log"

	"go.wit.com/gui"
	"go.wit.com/lib/gadgets"
	"go.wit.com/lib/gui/repostatus"
)

func doesExist(path string) bool {
	if _, err := os.Stat(path); err != nil {
		if os.IsNotExist(err) {
			return false
		}
	}
	return true
}

func globalBuildOptions(box *gui.Node) {
	var setCurrentBranch *gui.Node
	group1 := box.NewGroup("Global Build Options")
	groupvbox := group1.NewBox("bw vbox", false)
	// grouphbox := groupvbox.NewBox("bw hbox", true)

	grid := groupvbox.NewGrid("buildOptions", 2, 1)

	me.mainBranch = gadgets.NewBasicCombobox(grid, "default main branch")
	me.mainBranch.AddText("guimain")
	me.mainBranch.AddText("gitea server default")
	me.mainBranch.Disable()

	me.develBranch = gadgets.NewBasicCombobox(grid, "default devel branch")
	me.develBranch.AddText("devel")

	me.userBranch = gadgets.NewBasicCombobox(grid, "default user branch")
	me.userBranch.AddText("jcarr")

	// select the branch you want to test, build and develop against
	// this lets you select your user branch, but, when you are happy
	// you can merge everything into the devel branch and make sure it actually
	// works. Then, when that is good, merge and version everything in master
	guiBranch := gadgets.NewBasicCombobox(grid, "Set Current Working Branch")
	guiBranch.AddText("guimaster")
	guiBranch.AddText("guidevel")
	guiBranch.AddText("jcarr")
	guiBranch.Custom = func() {
		me.toMoveToBranch = guiBranch.String()
		setCurrentBranch.Set("set all branches to " + me.toMoveToBranch)
		me.mainBranch.Disable()
	}
	me.rerunGoMod = groupvbox.NewButton("re-run go mod & go tidy", func() {
		me.rerunGoMod.Disable()
		log.Warn("scanning allrepos")
		os.Unsetenv("GO111MODULE")
		for repo, path := range me.allrepos {
			var cmd []string
			var err error
			var b bool
			var output string

			log.Warn("found repo", path, repo.String())
			fullpath := "/home/jcarr/go/src/" + path

			me.rerunGoMod.SetText("Running go.mod " + fullpath)

			cmd = []string{"rm", "go.mod", "go.sum"}
			// log.Warn("Actually RUN path =", fullpath, "cmd =", cmd)
			err, b, output = repostatus.RunCmd(fullpath, cmd)
			log.Warn(err, b, string(output))

			log.Sleep(.1)

			cmd = []string{"go", "mod", "init"}
			// log.Warn("Actually RUN path =", fullpath, "cmd =", cmd)
			err, b, output = repostatus.RunCmd(fullpath, cmd)
			log.Warn(err, b, string(output))
			if err != nil {
				return
			}

			log.Sleep(.1)

			cmd = []string{"go", "mod", "tidy"}
			// log.Warn("Actually RUN path =", fullpath, "cmd =", cmd)
			err, b, output = repostatus.RunCmd(fullpath, cmd)
			log.Warn(err, b, string(output))
			if err != nil {
				return
			}

			log.Sleep(.2)

			cmd = []string{"git", "status"}
			// log.Warn("Actually RUN path =", fullpath, "cmd =", cmd)
			err, b, output = repostatus.RunCmd(fullpath, cmd)
			log.Warn(err, b, string(output))
		}
		me.rerunGoMod.SetText("re-run go mod & go tidy")
		me.rerunGoMod.Enable()
	})
	setCurrentBranch = groupvbox.NewButton("set all branches to", func() {
		log.Warn("scanning allrepos")
		for repo, path := range me.allrepos {
			log.Warn("found repo", repo.String())
			var changeBranch [][]string
			// realname, realversion := repo.status.CheckoutBranch(me.toMoveToBranch)
			// log.Warn("GOT", realname, realversion)
			// path := repo.status.GetPath()
			changeBranch = append(changeBranch, []string{"cd", "go/src/" + path})
			changeBranch = append(changeBranch, []string{"git", "checkout", me.toMoveToBranch})
			me.script = changeBranch
			setGitCommands()
			// goMake("--doit")
		}
	})
	var everything *gui.Node
	everything = groupvbox.NewButton("go get everything on go.wit.com", func() {
		var perfect bool = true
		var newCmds [][]string
		// usr, _ := user.Current()
		newCmds = append(newCmds, []string{"cd", "go/src/go.wit.com/apps/myrepos"})
		repos := myrepolist()
		for _, line := range repos {
			log.Warn("repo =", line)
			path, _, _, _ := splitLine(line)
			path = strings.TrimSpace(path)
			if path == "#" {
				// skip comment lines
				continue
			}
			if doesExist("/home/jcarr/go/src/" + path) {
				continue
			}
			newCmds = append(newCmds, []string{"go", "get", "-v", path})
			perfect = false
		}

		if perfect {
			var notes [][]string
			notes = append(notes, []string{"you have already downloaded"})
			notes = append(notes, []string{"everything on go.wit.com"})
			me.script = notes
			setGitCommands()
			doit.Disable()
			everything.Disable()
			return
		}

		me.script = newCmds
		doit.Enable()
		setGitCommands()
	})
	groupvbox.NewButton("build all apps", func() {
	})
}
